Package: isatabr
Type: Package
Date: 2022-08-19
Title: Implementation for the ISA Abstract Model
Version: 1.0.1
Description: ISA is a metadata framework to manage an increasingly diverse set 
    of life science, environmental and biomedical experiments. In isatabr 
    methods for reading, modifying and writing of files in the ISA-Tab format
    are implemented. It also contains methods for processing assay data.
Authors@R: c(
    person("Bart-Jan", "van Rossum", role = c("aut", "cre"),
           email = "bart-jan.vanrossum@wur.nl",
           comment = c(ORCID = "0000-0002-8673-2514")),
    person("Maikel", "Verouden", role = c("aut"),
           email = "maikel.verouden@wur.nl",
           comment = c(ORCID = "0000-0002-4893-3323")))
Encoding: UTF-8
Depends: methods
Suggests: tinytest, affy, Biobase, xcms, knitr, rmarkdown
License: GPL-3
URL: https://github.com/Biometris/isatabr/
BugReports: https://github.com/Biometris/isatabr/issues
RoxygenNote: 7.2.1
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2022-08-19 12:26:45 UTC; rossu027
Author: Bart-Jan van Rossum [aut, cre]
    (<https://orcid.org/0000-0002-8673-2514>),
  Maikel Verouden [aut] (<https://orcid.org/0000-0002-4893-3323>)
Maintainer: Bart-Jan van Rossum <bart-jan.vanrossum@wur.nl>
Repository: CRAN
Date/Publication: 2022-08-19 13:00:02 UTC
Built: R 4.6.0; ; 2026-04-25 19:46:31 UTC; unix
