# Generated by roxygen2: do not edit by hand

export("aFiles<-")
export("iContacts<-")
export("iFileName<-")
export("iPubs<-")
export("invest<-")
export("isaPath<-")
export("oSR<-")
export("sAssays<-")
export("sContacts<-")
export("sDD<-")
export("sFacts<-")
export("sFiles<-")
export("sProts<-")
export("sPubs<-")
export("study<-")
export(aFiles)
export(getAssayFileNames)
export(getAssayTabs)
export(getStudyFileNames)
export(iContacts)
export(iFileName)
export(iPubs)
export(invest)
export(isaPath)
export(oSR)
export(readISATab)
export(sAssays)
export(sContacts)
export(sDD)
export(sFacts)
export(sFiles)
export(sProts)
export(sPubs)
export(study)
export(validISAObject)
export(writeAssayFiles)
export(writeISAtab)
export(writeInvestigationFile)
export(writeStudyFiles)
exportClasses(ISA)
exportClasses(assayTab)
exportClasses(microarrayAssayTab)
exportClasses(msAssayTab)
exportMethods(initialize)
exportMethods(processAssay)
import(methods)
importFrom(utils,count.fields)
importFrom(utils,hasName)
importFrom(utils,person)
importFrom(utils,read.delim)
importFrom(utils,read.table)
importFrom(utils,write.table)
